# geeagri


[![image](https://img.shields.io/pypi/v/geeagri.svg)](https://pypi.python.org/pypi/geeagri)
[![image](https://img.shields.io/conda/vn/conda-forge/geeagri.svg)](https://anaconda.org/conda-forge/geeagri)


**Python tools for agricultural analysis powered by Google Earth Engine.**


-   Free software: MIT License
-   Documentation: https://geonextgis.github.io/geeagri
    

## Features

-   TODO
